aboutsummaryrefslogtreecommitdiff
path: root/engines/scumm
diff options
context:
space:
mode:
authorTarek Soliman2011-09-30 22:34:44 -0500
committerTarek Soliman2011-10-04 23:44:05 -0500
commit71f3c543652677c9c1a9ad066b0eaeaa632ad383 (patch)
tree0237d79e73db6c7fff256fa5bf7da7e863fceda5 /engines/scumm
parent80ddd7abe83174a4129e398ed73ebaf5dd920d6e (diff)
downloadscummvm-rg350-71f3c543652677c9c1a9ad066b0eaeaa632ad383.tar.gz
scummvm-rg350-71f3c543652677c9c1a9ad066b0eaeaa632ad383.tar.bz2
scummvm-rg350-71f3c543652677c9c1a9ad066b0eaeaa632ad383.zip
SCUMM: Apply modified patch from #3076698
This adds support for the Ultimate Talkie Edition fanpatch This is authored by the original UTE author LogicDeLuxe and Fingolfin. Modification: Removed detection entries
Diffstat (limited to 'engines/scumm')
-rw-r--r--engines/scumm/script_v5.cpp24
1 files changed, 18 insertions, 6 deletions
diff --git a/engines/scumm/script_v5.cpp b/engines/scumm/script_v5.cpp
index 02c8d977a5..6426b75e1e 100644
--- a/engines/scumm/script_v5.cpp
+++ b/engines/scumm/script_v5.cpp
@@ -1799,12 +1799,20 @@ void ScummEngine_v5::o5_roomOps() {
case 13: // SO_SAVE_STRING
{
// This subopcode is used in Indy 4 to save the IQ points data.
// No other game uses it. We use this to replace the given filename by
// one based on the targetname ("TARGET.iq").
// This way, the iq data of each Indy 4 variant a user might have stays
// separate. Moreover, the filename now clearly reflects to which target
// it belongs (as it should).
Common::String filename;
char chr;
@@ -1814,6 +1822,8 @@ void ScummEngine_v5::o5_roomOps() {
if (_game.id == GID_INDY4) {
filename = _targetName + ".iq";
+ } else if (_game.id == GID_MONKEY || _game.id == GID_MONKEY2) {
+ filename = _targetName + ".cfg";
} else {
error("SO_SAVE_STRING: Unsupported filename %s", filename.c_str());
}
@@ -1841,6 +1851,8 @@ void ScummEngine_v5::o5_roomOps() {
if (_game.id == GID_INDY4) {
filename = _targetName + ".iq";
+ } else if (_game.id == GID_MONKEY || _game.id == GID_MONKEY2) {
+ filename = _targetName + ".cfg";
} else {
error("SO_LOAD_STRING: Unsupported filename %s", filename.c_str());
}
@@ -1799,12 +1799,20 @@ void ScummEngine_v5::o5_roomOps() {
case 13: // SO_SAVE_STRING
{
- // This subopcode is used in Indy 4 to save the IQ points data.
- // No other game uses it. We use this to replace the given filename by
- // one based on the targetname ("TARGET.iq").
- // This way, the iq data of each Indy 4 variant a user might have stays
- // separate. Moreover, the filename now clearly reflects to which target
- // it belongs (as it should).
+ // This subopcode is used in Indy 4 to save the IQ points
+ // data. No other LucasArts game uses it. We use this fact
+ // to substitute a filename based on the targetname
+ // ("TARGET.iq").
+ //
+ // This way, the iq data of each Indy 4 variant stays
+ // separate. Moreover, the filename now clearly reflects to
+ // which target it belongs (as it should).
+ //
+ // In addition, the Monkey Island fan patch (which adds
+ // speech support and more things to MI 1 and 2) uses
+ // this opcode to generate a "monkey.cfg" file containing.
+ // some user controllable settings.
+ // Once more we use a custom filename ("TARGET.cfg").
Common::String filename;
char chr;